@@ -94,12 +94,10 @@ setMethod(
   "covariate_table",
   signature=signature(times="numeric"),
   definition=function (..., order = c("linear", "constant"), times) {
-
     order <- match.arg(order)
     env <- parent.frame(2)
-
     tryCatch(
-      covariate.table.internal(...,times=times,order=order,env=env),
+      covariate_table_internal(...,times=times,order=order,env=env),
       error = function (e) pStop("covariate_table",conditionMessage(e))
     )
 
@@ -112,19 +110,17 @@ setMethod(
   "covariate_table",
   signature=signature(times="character"),
   definition=function (..., order = c("linear", "constant"), times) {
-
     order <- match.arg(order)
     env <- parent.frame(2)
-
     tryCatch(
-      covariate.table.internal(...,.timevar=times,order=order,env=env),
+      covariate_table_internal(...,.timevar=times,order=order,env=env),
       error = function (e) pStop("covariate_table",conditionMessage(e))
     )
 
   }
 )
 
-covariate.table.internal <- function (..., times = NULL, .timevar = NULL,
+covariate_table_internal <- function (..., times = NULL, .timevar = NULL,
   order, env) {
 
   d <- as.list(substitute(list(...)))[-1]
