@@ -32,7 +32,7 @@
 ##' \item{\code{pmcmc}}{repeats the calculation, beginning with the last state}
 ##' \item{\code{\link{continue}}}{continues the \code{pmcmc} calculation}
 ##' \item{\code{plot}}{produces a series of diagnostic plots}
-##' \item{\code{\link{filter.traj}}}{extracts a random sample from the smoothing distribution}
+##' \item{\code{\link{filter_traj}}}{extracts a random sample from the smoothing distribution}
 ##' \item{\code{\link{traces}}}{produces an \code{\link[coda]{mcmc}} object, to which the various \pkg{coda} convergence diagnostics can be applied}
 ##' }
 ##'
@@ -109,7 +109,7 @@ setMethod(
     ..., verbose = getOption("verbose", FALSE)) {
 
     tryCatch(
-      pmcmc.internal(
+      pmcmc_internal(
         data,
         Nmcmc=Nmcmc,
         proposal=proposal,
@@ -139,7 +139,7 @@ setMethod(
     verbose = getOption("verbose", FALSE)) {
 
     tryCatch(
-      pmcmc.internal(
+      pmcmc_internal(
         data,
         Nmcmc=Nmcmc,
         proposal=proposal,
@@ -244,7 +244,7 @@ setMethod(
   }
 )
 
-pmcmc.internal <- function (object, Nmcmc, proposal, Np, ...,
+pmcmc_internal <- function (object, Nmcmc, proposal, Np, ...,
   verbose, .ndone = 0L, .accepts = 0L, .prev.pfp = NULL, .prev.log.prior = NULL,
   .gnsi = TRUE) {
 
